@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -24,9 +24,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <packagekit-glib/packagekit.h>
-
-#include "egg-debug.h"
+#include <packagekit-glib2/packagekit.h>
 
 #include "gpk-enum.h"
 #include "gpk-cell-renderer-info.h"
@@ -113,7 +111,7 @@ gpk_cell_renderer_info_set_property (GObject *object, guint param_id,
 		text = g_value_get_string (value);
 		split = g_strsplit (text, ",", -1);
 		for (i=0; split[i] != NULL; i++) {
-			info = pk_info_enum_from_text (split[i]);
+			info = pk_info_enum_from_string (split[i]);
 			g_ptr_array_add (cru->priv->ignore, GUINT_TO_POINTER (info));
 		}
 		g_strfreev (split);
@@ -140,14 +138,11 @@ gpk_cell_renderer_finalize (GObject *object)
 static void
 gpk_cell_renderer_info_class_init (GpkCellRendererInfoClass *class)
 {
-	GtkCellRendererClass *cell_renderer_class;
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
 	object_class->finalize = gpk_cell_renderer_finalize;
 
 	parent_class = g_type_class_peek_parent (class);
 
-	cell_renderer_class = GTK_CELL_RENDERER_CLASS (class);
-
 	object_class->get_property = gpk_cell_renderer_info_get_property;
 	object_class->set_property = gpk_cell_renderer_info_set_property;
 
