@@ -112,7 +112,13 @@ void		 gpk_dbus_install_gstreamer_resources	(GpkDbus 	*dbus,
 							 gchar		**codecs,
 							 const gchar	*interaction,
 							 DBusGMethodInvocation *context);
-void		 gpk_dbus_remove_package_by_file	(GpkDbus	*dbus,
+void		 gpk_dbus_install_resources		(GpkDbus 	*dbus,
+							 guint32	 xid,
+							 const gchar	*type,
+							 gchar		**resources,
+							 const gchar	*interaction,
+							 DBusGMethodInvocation *context);
+void		 gpk_dbus_remove_package_by_files	(GpkDbus	*dbus,
 							 guint32	 xid,
 							 gchar		**files,
 							 const gchar	*interaction,
